@@ -1,7 +1,7 @@
 # This file is part of pybliographer
 # 
-# Copyright (C) 1998,1999,2000 Frederic GOBRY
-# Email : gobry@idiap.ch
+# Copyright (C) 1998-2003 Frederic GOBRY
+# Email : gobry@pybliographer.org
 # 	   
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,46 +17,26 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Exceptions.py,v 1.4 2000/03/13 13:43:10 fredgo Exp $
+# 
 
 ''' This module defines some common exceptions '''
 
-import string
+class ParserError (Exception):
 
-def format (prefix, lines):
-    return prefix + string.join (lines, '\n' + prefix)
-    
-class ParserError:
+    def __init__ (self, msg, line = None):
+        Exception.__init__ (self, line, msg)
 
-    def __init__ (self, errors, file = None):
-        if file:
-            self.file = file + ':'
-        else:
-            self.file = ''
-            
-        self.errors = errors or []
-        return
+class SchemaError (Exception):
 
-    def __repr__ (self):
-        return format (self.file, self.errors)
-
-
-class SimpleError:
-    def __init__ (self, message):
-        self.message = message
-        return
-
-    def __repr__ (self):
-        return self.message
-    
-    
-class FormatError (SimpleError):
     pass
 
+class ConstraintError (Exception):
 
-class FileError (SimpleError):
     pass
 
+class InvalidQuery (Exception):
 
-class DateError (SimpleError):
+    """ Raised if an ill-typed query is attempted """
+    
     pass
+
